#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hedgehog-fn
version:              1.1
visibility:           public
id:                   hedgehog-fn-1.1-9I3oWCNjP4e467FrR9NW4D
key:                  hedgehog-fn-1.1-9I3oWCNjP4e467FrR9NW4D
license:              BSD-3-Clause
maintainer:           Queensland Functional Programming Lab <oᴉ˙ldɟb@llǝʞsɐɥ>
author:               Isaac Elliott
homepage:             https://github.com/qfpl/hedgehog-fn
synopsis:             Function generation for `hedgehog`
description:
    Generating shrinkable, showable functions with `hedgehog`. See
    `Hedgehog.Function` for example usages.

category:             Testing
abi:                  769f158ef2aa8beeea202cb4b8538be9
exposed:              True
exposed-modules:      Hedgehog.Function Hedgehog.Function.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hedgehog-fn-1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hedgehog-fn-1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hedgehog-fn-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hedgehog-fn
hs-libraries:         HShedgehog-fn-1.1-9I3oWCNjP4e467FrR9NW4D
depends:
    base-4.18.2.1 contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    hedgehog-1.5-IaW63ulaaCn5LSEEe4ccnl transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-hedgehog-fn/html/hedgehog-fn.haddock
haddock-html:         /usr/share/doc/haskell-hedgehog-fn/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

